from lxml import etree
import json

FILES = [
    r"../profiles/default/registry/icons_bootstrap.xml",
    r"../profiles/default/registry/icons_contenttype.xml",
    r"../profiles/default/registry/icons_country_flags.xml",
    r"../profiles/default/registry/icons_language_flags.xml",
    r"../profiles/default/registry/icons_mimetype.xml",
    r"../profiles/default/registry/icons_plone.xml",
    r"../profiles/default/registry/icons_toolbar.xml",
]

PATH_ICONMAP = "../static/iconmap.json"


def main():
    iconmap = {}
    for file in FILES:
        root = etree.parse(file)
        for record in root.xpath("//record"):
            iconmap[record.get("name")] = record.xpath("value")[0].text

    with open(PATH_ICONMAP, "w") as f:
        f.write(json.dumps(iconmap, indent=4, sort_keys=True))


if __name__ == "__main__":
    main()



"""Setup tests for this package."""
from plone.registry.interfaces import IRegistry
from plone.staticresources.testing import (
    PLONE_STATICRESOURCES_INTEGRATION_TESTING,
)
from zope.component import getMultiAdapter
from zope.component import getUtility

import unittest


class TestSetup(unittest.TestCase):
    """Test that plone.staticresources is properly installed."""

    layer = PLONE_STATICRESOURCES_INTEGRATION_TESTING

    def setUp(self):
        """Custom shared utility setup for tests."""
        self.portal = self.layer["portal"]
        self.request = self.layer["request"]
        self.installer = getMultiAdapter(
            (self.portal, self.request), name=u"prefs_install_products_form"
        )
        self.registry = getUtility(IRegistry)

    def test_install(self):
        """Test if plone.staticresources is installed."""
        self.assertTrue(self.installer.is_product_installed("plone.staticresources"))

        # Test availability of bundles and resources
        self.assertEqual(
            self.registry.records.get("plone.bundles/plone.jscompilation").value,
            "++plone++static/bundle-plone/bundle.min.js",
        )

        self.assertEqual(
            self.registry.records.get("plone.icon.activity").value,
            "++plone++bootstrap-icons/activity.svg",
        )

    def test_uninstall(self):
        """Test if plone.staticresources can be uninstalled."""
        self.installer.uninstall_product("plone.staticresources")
        self.assertFalse(self.installer.is_product_installed("plone.staticresources"))

        # This one is removed
        self.assertEqual(self.registry.records.get("plone.bundles/plone"), None)



from plone.app.testing import applyProfile
from plone.app.testing import IntegrationTesting
from plone.app.testing import PloneSandboxLayer
from plone.app.testing.layers import PLONE_FIXTURE

import plone.staticresources


class PloneStaticresourcesLayer(PloneSandboxLayer):

    defaultBases = (PLONE_FIXTURE,)

    def setUpZope(self, app, configurationContext):
        self.loadZCML(package=plone.staticresources)

    def setUpPloneSite(self, portal):
        applyProfile(portal, "plone.staticresources:default")


PLONE_STATICRESOURCES_FIXTURE = PloneStaticresourcesLayer()


PLONE_STATICRESOURCES_INTEGRATION_TESTING = IntegrationTesting(
    bases=(PLONE_STATICRESOURCES_FIXTURE,),
    name="PloneStaticresourcesLayer:IntegrationTesting",
)



import os

this_dir = os.path.dirname(os.path.realpath(__file__))

ICONS_DIR = "{dir}/../static/icons-bootstrap".format(dir=this_dir)
OUTPUT_FILE = "{dir}/../profiles/default/registry/icons_bootstrap.xml".format(
    dir=this_dir
)

registry_template = """<?xml version="1.0"?>
<registry>
{}
</registry>
"""

entry = """
  <record name="plone.icon.{icon}">
    <field type="plone.registry.field.TextLine">
      <title>Bootstrap Icon {icon}</title>
    </field>
    <value key="resource">++plone++bootstrap-icons/{icon}.svg</value>
  </record>
"""


def main():
    output = ""

    for item in sorted(os.listdir(ICONS_DIR)):
        if item.endswith(".svg"):
            icon = item[:-4]
            output = output + entry.format(icon=icon)

    output = registry_template.format(output)

    with open(OUTPUT_FILE, "w") as f:
        f.write(output)

    print("Done.")
    print("If any new icons were added also add an upgrade step!")


if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-
import os
import json

this_dir = os.path.dirname(os.path.realpath(__file__))

# Part Register Country Flag Icons
DATA_FILE_COUNTRY = "{dir}/../static/icons-country-flags/countries.json".format(
    dir=this_dir
)
OUTPUT_FILE_COUNTRY = (
    "{dir}/../profiles/default/registry/icons_country_flags.xml".format(dir=this_dir)
)

DEFAULT_PATTERN_COUNTRY = """
<record name="plone.icon.countryflag">
  <field type="plone.registry.field.TextLine">
    <title>Country Icon Flag Default</title>
  </field>
  <value key="resource">++plone++bootstrap-icons/flag.svg</value>
</record>
"""

PATTERN_COUNTRY = """
<record name="plone.icon.countryflag/##KEY##">
  <field type="plone.registry.field.TextLine">
    <title>Country Icon Flag ##NAME##</title>
  </field>
  <value key="resource">++plone++country-flag-icons/##KEY##.svg</value>
</record>
"""


# Part Register Language Flag Icons
DATA_FILE_LANGUAGE = "{dir}/../static/icons-language-flags/languages.json".format(
    dir=this_dir
)
OUTPUT_FILE_LANGUAGE = (
    "{dir}/../profiles/default/registry/icons_language_flags.xml".format(dir=this_dir)
)

DEFAULT_PATTERN_LANGUAGE = """
<record name="plone.icon.languageflag">
  <field type="plone.registry.field.TextLine">
    <title>Language Icon Flag Default</title>
  </field>
  <value key="resource">++plone++bootstrap-icons/flag.svg</value>
</record>
"""

PATTERN_LANGUAGE = """
<record name="plone.icon.languageflag/##KEY##">
  <field type="plone.registry.field.TextLine">
    <title>Language Icon Flag ##NAME##</title>
  </field>
  <value key="resource">++plone++language-flag-icons/##KEY##.svg</value>
</record>
"""


def registry_writer(datafile, output, default_pattern, pattern):

    entries = []
    entries.append(default_pattern)

    with open(datafile, "r") as countries:
        data = countries.read()
        countries_data = json.loads(data)

        for key, name in countries_data.items():
            entry = pattern.replace("##KEY##", key.lower()).replace(
                "##NAME##", name.lower()
            )
            entries.append(entry)

    if entries:
        with open(output, "w") as f:
            f.write(
                '<?xml version="1.0"?>\n<registry>' + "".join(entries) + "\n</registry>"
            )
            f.close()
    print("Done.")
    print("If any new icons were added also add an upgrade step!")


def main():

    registry_writer(
        DATA_FILE_COUNTRY, OUTPUT_FILE_COUNTRY, DEFAULT_PATTERN_COUNTRY, PATTERN_COUNTRY
    )

    registry_writer(
        DATA_FILE_LANGUAGE,
        OUTPUT_FILE_LANGUAGE,
        DEFAULT_PATTERN_LANGUAGE,
        PATTERN_LANGUAGE,
    )


if __name__ == "__main__":
    main()



from zope.interface import implementer


try:
    from Products.CMFPlone.interfaces import INonInstallable
except ImportError:
    from zope.interface import Interface

    class INonInstallable(Interface):
        pass


@implementer(INonInstallable)
class HiddenProfiles(object):
    def getNonInstallableProfiles(self):
        """Hide all profiles from site-creation and quickinstaller."""
        return [
            "plone.staticresources:default",
            "plone.staticresources:last_compilation",
            "plone.staticresources:async",
            "plone.staticresources:uninstall",
        ]

    def getNonInstallableProducts(self):
        """Hide the upgrades package from site-creation and quickinstaller.

        Our upgrades profiles are defined in the directory 'upgrades'.
        Plone sees this is a separate product.
        So instead of adding each new upgrade profile to the list of
        non installable profiles above, we can mark the upgrades product
        as non installable.
        """
        return ["plone.staticresources.upgrades"]



"""Installer for the plone.staticresources package."""

from setuptools import find_packages
from setuptools import setup


long_description = "\n\n".join(
    [
        open("README.rst").read(),
        open("CHANGES.rst").read(),
    ]
)


setup(
    name="plone.staticresources",
    version="2.0.0",
    description="Static resources for Plone",
    long_description=long_description,
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Web Environment",
        "Framework :: Plone",
        "Framework :: Plone :: 6.0",
        "Framework :: Plone :: Core",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Operating System :: OS Independent",
        "License :: OSI Approved :: GNU General Public License v2 (GPLv2)",
    ],
    keywords="Python Plone",
    author="Plone Foundation",
    author_email="plone-developers@lists.sourceforge.net",
    url="https://github.com/plone/plone.staticresources",
    license="GPL version 2",
    packages=find_packages("src", exclude=["ez_setup"]),
    namespace_packages=["plone"],
    package_dir={"": "src"},
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        "Products.GenericSetup",
        "setuptools",
        "plone.resource",
    ],
    extras_require={
        "test": [
            "plone.app.testing",
            "plone.testing",
        ],
    },
    entry_points="""
    [console_scripts]
    plone-register-icons = plone.staticresources._scripts.register_icons:main
    plone-register-flags = plone.staticresources._scripts.register_flag_icons:main
    [z3c.autoinclude.plugin]
    target = plone
    """,  # noqa
)
